# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_deviceauth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_deviceauth.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1esteammessages_deviceauth.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"X\n+CDeviceAuth_GetOwnAuthorizedDevices_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x18\n\x10include_canceled\x18\x02 \x01(\x08\"\xb8\x02\n,CDeviceAuth_GetOwnAuthorizedDevices_Response\x12\x45\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x34.CDeviceAuth_GetOwnAuthorizedDevices_Response.Device\x1a\xc0\x01\n\x06\x44\x65vice\x12\x19\n\x11\x61uth_device_token\x18\x01 \x01(\x06\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x12\n\nis_pending\x18\x03 \x01(\x08\x12\x13\n\x0bis_canceled\x18\x04 \x01(\x08\x12\x16\n\x0elast_time_used\x18\x05 \x01(\r\x12\x18\n\x10last_borrower_id\x18\x06 \x01(\x06\x12\x17\n\x0flast_app_played\x18\x07 \x01(\r\x12\x12\n\nis_limited\x18\x08 \x01(\x08\"\x85\x01\n.CDeviceAuth_AcceptAuthorizationRequest_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x19\n\x11\x61uth_device_token\x18\x02 \x01(\x06\x12\x11\n\tauth_code\x18\x03 \x01(\x06\x12\x14\n\x0c\x66rom_steamid\x18\x04 \x01(\x06\"1\n/CDeviceAuth_AcceptAuthorizationRequest_Response\"W\n)CDeviceAuth_AuthorizeRemoteDevice_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x19\n\x11\x61uth_device_token\x18\x02 \x01(\x06\",\n*CDeviceAuth_AuthorizeRemoteDevice_Response\"Y\n+CDeviceAuth_DeauthorizeRemoteDevice_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x19\n\x11\x61uth_device_token\x18\x02 \x01(\x06\".\n,CDeviceAuth_DeauthorizeRemoteDevice_Response\"?\n,CDeviceAuth_GetUsedAuthorizedDevices_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\xfa\x01\n-CDeviceAuth_GetUsedAuthorizedDevices_Response\x12\x46\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x35.CDeviceAuth_GetUsedAuthorizedDevices_Response.Device\x1a\x80\x01\n\x06\x44\x65vice\x12\x19\n\x11\x61uth_device_token\x18\x01 \x01(\x06\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x15\n\rowner_steamid\x18\x03 \x01(\x06\x12\x16\n\x0elast_time_used\x18\x04 \x01(\r\x12\x17\n\x0flast_app_played\x18\x05 \x01(\r\"p\n*CDeviceAuth_GetAuthorizedBorrowers_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x18\n\x10include_canceled\x18\x02 \x01(\x08\x12\x17\n\x0finclude_pending\x18\x03 \x01(\x08\"\xd3\x01\n+CDeviceAuth_GetAuthorizedBorrowers_Response\x12H\n\tborrowers\x18\x01 \x03(\x0b\x32\x35.CDeviceAuth_GetAuthorizedBorrowers_Response.Borrower\x1aZ\n\x08\x42orrower\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x12\n\nis_pending\x18\x02 \x01(\x08\x12\x13\n\x0bis_canceled\x18\x03 \x01(\x08\x12\x14\n\x0ctime_created\x18\x04 \x01(\r\"W\n*CDeviceAuth_AddAuthorizedBorrowers_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x18\n\x10steamid_borrower\x18\x02 \x03(\x06\"F\n+CDeviceAuth_AddAuthorizedBorrowers_Response\x12\x17\n\x0fseconds_to_wait\x18\x01 \x01(\x05\"Z\n-CDeviceAuth_RemoveAuthorizedBorrowers_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x18\n\x10steamid_borrower\x18\x02 \x03(\x06\"0\n.CDeviceAuth_RemoveAuthorizedBorrowers_Response\"q\n+CDeviceAuth_GetAuthorizedAsBorrower_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x18\n\x10include_canceled\x18\x02 \x01(\x08\x12\x17\n\x0finclude_pending\x18\x03 \x01(\x08\"\xe0\x01\n,CDeviceAuth_GetAuthorizedAsBorrower_Response\x12\x45\n\x07lenders\x18\x01 \x03(\x0b\x32\x34.CDeviceAuth_GetAuthorizedAsBorrower_Response.Lender\x1ai\n\x06Lender\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0ctime_created\x18\x02 \x01(\r\x12\x12\n\nis_pending\x18\x03 \x01(\x08\x12\x13\n\x0bis_canceled\x18\x04 \x01(\x08\x12\x0f\n\x07is_used\x18\x05 \x01(\x08\"@\n-CDeviceAuth_GetExcludedGamesInLibrary_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\xe6\x01\n.CDeviceAuth_GetExcludedGamesInLibrary_Response\x12T\n\x0e\x65xcluded_games\x18\x01 \x03(\x0b\x32<.CDeviceAuth_GetExcludedGamesInLibrary_Response.ExcludedGame\x1a^\n\x0c\x45xcludedGame\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tgame_name\x18\x02 \x01(\t\x12\x12\n\nvac_banned\x18\x03 \x01(\x08\x12\x18\n\x10package_excluded\x18\x04 \x01(\x08\"=\n*CDeviceAuth_GetBorrowerPlayHistory_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\xb8\x02\n+CDeviceAuth_GetBorrowerPlayHistory_Response\x12R\n\x0elender_history\x18\x01 \x03(\x0b\x32:.CDeviceAuth_GetBorrowerPlayHistory_Response.LenderHistory\x1a\x43\n\x0bGameHistory\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\ttime_last\x18\x02 \x01(\r\x12\x12\n\ntime_total\x18\x03 \x01(\r\x1ap\n\rLenderHistory\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12N\n\x0cgame_history\x18\x02 \x03(\x0b\x32\x38.CDeviceAuth_GetBorrowerPlayHistory_Response.GameHistory2\xc2\x0f\n\nDeviceAuth\x12\x9a\x01\n\x17GetOwnAuthorizedDevices\x12,.CDeviceAuth_GetOwnAuthorizedDevices_Request\x1a-.CDeviceAuth_GetOwnAuthorizedDevices_Response\"\"\x82\xb5\x18\x1eGet list of authorized devices\x12\xb5\x01\n\x1a\x41\x63\x63\x65ptAuthorizationRequest\x12/.CDeviceAuth_AcceptAuthorizationRequest_Request\x1a\x30.CDeviceAuth_AcceptAuthorizationRequest_Response\"4\x82\xb5\x18\x30\x41\x63\x63\x65pt an authorization request by another users\x12\xaa\x01\n\x15\x41uthorizeRemoteDevice\x12*.CDeviceAuth_AuthorizeRemoteDevice_Request\x1a+.CDeviceAuth_AuthorizeRemoteDevice_Response\"8\x82\xb5\x18\x34\x41uthorize own remote device that has pending request\x12\x9b\x01\n\x17\x44\x65\x61uthorizeRemoteDevice\x12,.CDeviceAuth_DeauthorizeRemoteDevice_Request\x1a-.CDeviceAuth_DeauthorizeRemoteDevice_Response\"#\x82\xb5\x18\x1fRevoke own device authorization\x12\xbb\x01\n\x18GetUsedAuthorizedDevices\x12-.CDeviceAuth_GetUsedAuthorizedDevices_Request\x1a..CDeviceAuth_GetUsedAuthorizedDevices_Response\"@\x82\xb5\x18<Get list of authorized devices user played borrowed games on\x12\xb2\x01\n\x16GetAuthorizedBorrowers\x12+.CDeviceAuth_GetAuthorizedBorrowers_Request\x1a,.CDeviceAuth_GetAuthorizedBorrowers_Response\"=\x82\xb5\x18\x39Get list of users that can borrow on an authorized device\x12\xb0\x01\n\x16\x41\x64\x64\x41uthorizedBorrowers\x12+.CDeviceAuth_AddAuthorizedBorrowers_Request\x1a,.CDeviceAuth_AddAuthorizedBorrowers_Response\";\x82\xb5\x18\x37\x41\x64\x64 users that can borrow on limited authorized devices\x12\xbc\x01\n\x19RemoveAuthorizedBorrowers\x12..CDeviceAuth_RemoveAuthorizedBorrowers_Request\x1a/.CDeviceAuth_RemoveAuthorizedBorrowers_Response\">\x82\xb5\x18:Remove users that can borrow on limited authorized devices\x12\xb9\x01\n\x17GetAuthorizedAsBorrower\x12,.CDeviceAuth_GetAuthorizedAsBorrower_Request\x1a-.CDeviceAuth_GetAuthorizedAsBorrower_Response\"A\x82\xb5\x18=Get list of lenders that authorized given account as borrower\x12\xaf\x01\n\x19GetExcludedGamesInLibrary\x12..CDeviceAuth_GetExcludedGamesInLibrary_Request\x1a/.CDeviceAuth_GetExcludedGamesInLibrary_Response\"1\x82\xb5\x18-Get list of excluded games in lenders library\x12\x9a\x01\n\x16GetBorrowerPlayHistory\x12+.CDeviceAuth_GetBorrowerPlayHistory_Request\x1a,.CDeviceAuth_GetBorrowerPlayHistory_Response\"%\x82\xb5\x18!Get list played games as borrower\x1a$\x82\xb5\x18 Library Sharing settings serviceB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CDEVICEAUTH_GETOWNAUTHORIZEDDEVICES_REQUEST = _descriptor.Descriptor(
  name='CDeviceAuth_GetOwnAuthorizedDevices_Request',
  full_name='CDeviceAuth_GetOwnAuthorizedDevices_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CDeviceAuth_GetOwnAuthorizedDevices_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_canceled', full_name='CDeviceAuth_GetOwnAuthorizedDevices_Request.include_canceled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=182,
)


_CDEVICEAUTH_GETOWNAUTHORIZEDDEVICES_RESPONSE_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='CDeviceAuth_GetOwnAuthorizedDevices_Response.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_device_token', full_name='CDeviceAuth_GetOwnAuthorizedDevices_Response.Device.auth_device_token', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='CDeviceAuth_GetOwnAuthorizedDevices_Response.Device.device_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_pending', full_name='CDeviceAuth_GetOwnAuthorizedDevices_Response.Device.is_pending', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_canceled', full_name='CDeviceAuth_GetOwnAuthorizedDevices_Response.Device.is_canceled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_time_used', full_name='CDeviceAuth_GetOwnAuthorizedDevices_Response.Device.last_time_used', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_borrower_id', full_name='CDeviceAuth_GetOwnAuthorizedDevices_Response.Device.last_borrower_id', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_app_played', full_name='CDeviceAuth_GetOwnAuthorizedDevices_Response.Device.last_app_played', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_limited', full_name='CDeviceAuth_GetOwnAuthorizedDevices_Response.Device.is_limited', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=497,
)

_CDEVICEAUTH_GETOWNAUTHORIZEDDEVICES_RESPONSE = _descriptor.Descriptor(
  name='CDeviceAuth_GetOwnAuthorizedDevices_Response',
  full_name='CDeviceAuth_GetOwnAuthorizedDevices_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='devices', full_name='CDeviceAuth_GetOwnAuthorizedDevices_Response.devices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CDEVICEAUTH_GETOWNAUTHORIZEDDEVICES_RESPONSE_DEVICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=497,
)


_CDEVICEAUTH_ACCEPTAUTHORIZATIONREQUEST_REQUEST = _descriptor.Descriptor(
  name='CDeviceAuth_AcceptAuthorizationRequest_Request',
  full_name='CDeviceAuth_AcceptAuthorizationRequest_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CDeviceAuth_AcceptAuthorizationRequest_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_device_token', full_name='CDeviceAuth_AcceptAuthorizationRequest_Request.auth_device_token', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_code', full_name='CDeviceAuth_AcceptAuthorizationRequest_Request.auth_code', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_steamid', full_name='CDeviceAuth_AcceptAuthorizationRequest_Request.from_steamid', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=633,
)


_CDEVICEAUTH_ACCEPTAUTHORIZATIONREQUEST_RESPONSE = _descriptor.Descriptor(
  name='CDeviceAuth_AcceptAuthorizationRequest_Response',
  full_name='CDeviceAuth_AcceptAuthorizationRequest_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=635,
  serialized_end=684,
)


_CDEVICEAUTH_AUTHORIZEREMOTEDEVICE_REQUEST = _descriptor.Descriptor(
  name='CDeviceAuth_AuthorizeRemoteDevice_Request',
  full_name='CDeviceAuth_AuthorizeRemoteDevice_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CDeviceAuth_AuthorizeRemoteDevice_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_device_token', full_name='CDeviceAuth_AuthorizeRemoteDevice_Request.auth_device_token', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=686,
  serialized_end=773,
)


_CDEVICEAUTH_AUTHORIZEREMOTEDEVICE_RESPONSE = _descriptor.Descriptor(
  name='CDeviceAuth_AuthorizeRemoteDevice_Response',
  full_name='CDeviceAuth_AuthorizeRemoteDevice_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=819,
)


_CDEVICEAUTH_DEAUTHORIZEREMOTEDEVICE_REQUEST = _descriptor.Descriptor(
  name='CDeviceAuth_DeauthorizeRemoteDevice_Request',
  full_name='CDeviceAuth_DeauthorizeRemoteDevice_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CDeviceAuth_DeauthorizeRemoteDevice_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_device_token', full_name='CDeviceAuth_DeauthorizeRemoteDevice_Request.auth_device_token', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=821,
  serialized_end=910,
)


_CDEVICEAUTH_DEAUTHORIZEREMOTEDEVICE_RESPONSE = _descriptor.Descriptor(
  name='CDeviceAuth_DeauthorizeRemoteDevice_Response',
  full_name='CDeviceAuth_DeauthorizeRemoteDevice_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=912,
  serialized_end=958,
)


_CDEVICEAUTH_GETUSEDAUTHORIZEDDEVICES_REQUEST = _descriptor.Descriptor(
  name='CDeviceAuth_GetUsedAuthorizedDevices_Request',
  full_name='CDeviceAuth_GetUsedAuthorizedDevices_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CDeviceAuth_GetUsedAuthorizedDevices_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=960,
  serialized_end=1023,
)


_CDEVICEAUTH_GETUSEDAUTHORIZEDDEVICES_RESPONSE_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='CDeviceAuth_GetUsedAuthorizedDevices_Response.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_device_token', full_name='CDeviceAuth_GetUsedAuthorizedDevices_Response.Device.auth_device_token', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='CDeviceAuth_GetUsedAuthorizedDevices_Response.Device.device_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_steamid', full_name='CDeviceAuth_GetUsedAuthorizedDevices_Response.Device.owner_steamid', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_time_used', full_name='CDeviceAuth_GetUsedAuthorizedDevices_Response.Device.last_time_used', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_app_played', full_name='CDeviceAuth_GetUsedAuthorizedDevices_Response.Device.last_app_played', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1148,
  serialized_end=1276,
)

_CDEVICEAUTH_GETUSEDAUTHORIZEDDEVICES_RESPONSE = _descriptor.Descriptor(
  name='CDeviceAuth_GetUsedAuthorizedDevices_Response',
  full_name='CDeviceAuth_GetUsedAuthorizedDevices_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='devices', full_name='CDeviceAuth_GetUsedAuthorizedDevices_Response.devices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CDEVICEAUTH_GETUSEDAUTHORIZEDDEVICES_RESPONSE_DEVICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1026,
  serialized_end=1276,
)


_CDEVICEAUTH_GETAUTHORIZEDBORROWERS_REQUEST = _descriptor.Descriptor(
  name='CDeviceAuth_GetAuthorizedBorrowers_Request',
  full_name='CDeviceAuth_GetAuthorizedBorrowers_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CDeviceAuth_GetAuthorizedBorrowers_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_canceled', full_name='CDeviceAuth_GetAuthorizedBorrowers_Request.include_canceled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_pending', full_name='CDeviceAuth_GetAuthorizedBorrowers_Request.include_pending', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1278,
  serialized_end=1390,
)


_CDEVICEAUTH_GETAUTHORIZEDBORROWERS_RESPONSE_BORROWER = _descriptor.Descriptor(
  name='Borrower',
  full_name='CDeviceAuth_GetAuthorizedBorrowers_Response.Borrower',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CDeviceAuth_GetAuthorizedBorrowers_Response.Borrower.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_pending', full_name='CDeviceAuth_GetAuthorizedBorrowers_Response.Borrower.is_pending', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_canceled', full_name='CDeviceAuth_GetAuthorizedBorrowers_Response.Borrower.is_canceled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_created', full_name='CDeviceAuth_GetAuthorizedBorrowers_Response.Borrower.time_created', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1514,
  serialized_end=1604,
)

_CDEVICEAUTH_GETAUTHORIZEDBORROWERS_RESPONSE = _descriptor.Descriptor(
  name='CDeviceAuth_GetAuthorizedBorrowers_Response',
  full_name='CDeviceAuth_GetAuthorizedBorrowers_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='borrowers', full_name='CDeviceAuth_GetAuthorizedBorrowers_Response.borrowers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CDEVICEAUTH_GETAUTHORIZEDBORROWERS_RESPONSE_BORROWER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1393,
  serialized_end=1604,
)


_CDEVICEAUTH_ADDAUTHORIZEDBORROWERS_REQUEST = _descriptor.Descriptor(
  name='CDeviceAuth_AddAuthorizedBorrowers_Request',
  full_name='CDeviceAuth_AddAuthorizedBorrowers_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CDeviceAuth_AddAuthorizedBorrowers_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_borrower', full_name='CDeviceAuth_AddAuthorizedBorrowers_Request.steamid_borrower', index=1,
      number=2, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1606,
  serialized_end=1693,
)


_CDEVICEAUTH_ADDAUTHORIZEDBORROWERS_RESPONSE = _descriptor.Descriptor(
  name='CDeviceAuth_AddAuthorizedBorrowers_Response',
  full_name='CDeviceAuth_AddAuthorizedBorrowers_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seconds_to_wait', full_name='CDeviceAuth_AddAuthorizedBorrowers_Response.seconds_to_wait', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1695,
  serialized_end=1765,
)


_CDEVICEAUTH_REMOVEAUTHORIZEDBORROWERS_REQUEST = _descriptor.Descriptor(
  name='CDeviceAuth_RemoveAuthorizedBorrowers_Request',
  full_name='CDeviceAuth_RemoveAuthorizedBorrowers_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CDeviceAuth_RemoveAuthorizedBorrowers_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_borrower', full_name='CDeviceAuth_RemoveAuthorizedBorrowers_Request.steamid_borrower', index=1,
      number=2, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1767,
  serialized_end=1857,
)


_CDEVICEAUTH_REMOVEAUTHORIZEDBORROWERS_RESPONSE = _descriptor.Descriptor(
  name='CDeviceAuth_RemoveAuthorizedBorrowers_Response',
  full_name='CDeviceAuth_RemoveAuthorizedBorrowers_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1859,
  serialized_end=1907,
)


_CDEVICEAUTH_GETAUTHORIZEDASBORROWER_REQUEST = _descriptor.Descriptor(
  name='CDeviceAuth_GetAuthorizedAsBorrower_Request',
  full_name='CDeviceAuth_GetAuthorizedAsBorrower_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CDeviceAuth_GetAuthorizedAsBorrower_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_canceled', full_name='CDeviceAuth_GetAuthorizedAsBorrower_Request.include_canceled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_pending', full_name='CDeviceAuth_GetAuthorizedAsBorrower_Request.include_pending', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1909,
  serialized_end=2022,
)


_CDEVICEAUTH_GETAUTHORIZEDASBORROWER_RESPONSE_LENDER = _descriptor.Descriptor(
  name='Lender',
  full_name='CDeviceAuth_GetAuthorizedAsBorrower_Response.Lender',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CDeviceAuth_GetAuthorizedAsBorrower_Response.Lender.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_created', full_name='CDeviceAuth_GetAuthorizedAsBorrower_Response.Lender.time_created', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_pending', full_name='CDeviceAuth_GetAuthorizedAsBorrower_Response.Lender.is_pending', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_canceled', full_name='CDeviceAuth_GetAuthorizedAsBorrower_Response.Lender.is_canceled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_used', full_name='CDeviceAuth_GetAuthorizedAsBorrower_Response.Lender.is_used', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2144,
  serialized_end=2249,
)

_CDEVICEAUTH_GETAUTHORIZEDASBORROWER_RESPONSE = _descriptor.Descriptor(
  name='CDeviceAuth_GetAuthorizedAsBorrower_Response',
  full_name='CDeviceAuth_GetAuthorizedAsBorrower_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lenders', full_name='CDeviceAuth_GetAuthorizedAsBorrower_Response.lenders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CDEVICEAUTH_GETAUTHORIZEDASBORROWER_RESPONSE_LENDER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2025,
  serialized_end=2249,
)


_CDEVICEAUTH_GETEXCLUDEDGAMESINLIBRARY_REQUEST = _descriptor.Descriptor(
  name='CDeviceAuth_GetExcludedGamesInLibrary_Request',
  full_name='CDeviceAuth_GetExcludedGamesInLibrary_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CDeviceAuth_GetExcludedGamesInLibrary_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2251,
  serialized_end=2315,
)


_CDEVICEAUTH_GETEXCLUDEDGAMESINLIBRARY_RESPONSE_EXCLUDEDGAME = _descriptor.Descriptor(
  name='ExcludedGame',
  full_name='CDeviceAuth_GetExcludedGamesInLibrary_Response.ExcludedGame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CDeviceAuth_GetExcludedGamesInLibrary_Response.ExcludedGame.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_name', full_name='CDeviceAuth_GetExcludedGamesInLibrary_Response.ExcludedGame.game_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vac_banned', full_name='CDeviceAuth_GetExcludedGamesInLibrary_Response.ExcludedGame.vac_banned', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='package_excluded', full_name='CDeviceAuth_GetExcludedGamesInLibrary_Response.ExcludedGame.package_excluded', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2454,
  serialized_end=2548,
)

_CDEVICEAUTH_GETEXCLUDEDGAMESINLIBRARY_RESPONSE = _descriptor.Descriptor(
  name='CDeviceAuth_GetExcludedGamesInLibrary_Response',
  full_name='CDeviceAuth_GetExcludedGamesInLibrary_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='excluded_games', full_name='CDeviceAuth_GetExcludedGamesInLibrary_Response.excluded_games', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CDEVICEAUTH_GETEXCLUDEDGAMESINLIBRARY_RESPONSE_EXCLUDEDGAME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2318,
  serialized_end=2548,
)


_CDEVICEAUTH_GETBORROWERPLAYHISTORY_REQUEST = _descriptor.Descriptor(
  name='CDeviceAuth_GetBorrowerPlayHistory_Request',
  full_name='CDeviceAuth_GetBorrowerPlayHistory_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CDeviceAuth_GetBorrowerPlayHistory_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2550,
  serialized_end=2611,
)


_CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE_GAMEHISTORY = _descriptor.Descriptor(
  name='GameHistory',
  full_name='CDeviceAuth_GetBorrowerPlayHistory_Response.GameHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CDeviceAuth_GetBorrowerPlayHistory_Response.GameHistory.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_last', full_name='CDeviceAuth_GetBorrowerPlayHistory_Response.GameHistory.time_last', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_total', full_name='CDeviceAuth_GetBorrowerPlayHistory_Response.GameHistory.time_total', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2745,
  serialized_end=2812,
)

_CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE_LENDERHISTORY = _descriptor.Descriptor(
  name='LenderHistory',
  full_name='CDeviceAuth_GetBorrowerPlayHistory_Response.LenderHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CDeviceAuth_GetBorrowerPlayHistory_Response.LenderHistory.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_history', full_name='CDeviceAuth_GetBorrowerPlayHistory_Response.LenderHistory.game_history', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2814,
  serialized_end=2926,
)

_CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE = _descriptor.Descriptor(
  name='CDeviceAuth_GetBorrowerPlayHistory_Response',
  full_name='CDeviceAuth_GetBorrowerPlayHistory_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lender_history', full_name='CDeviceAuth_GetBorrowerPlayHistory_Response.lender_history', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE_GAMEHISTORY, _CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE_LENDERHISTORY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2614,
  serialized_end=2926,
)

_CDEVICEAUTH_GETOWNAUTHORIZEDDEVICES_RESPONSE_DEVICE.containing_type = _CDEVICEAUTH_GETOWNAUTHORIZEDDEVICES_RESPONSE
_CDEVICEAUTH_GETOWNAUTHORIZEDDEVICES_RESPONSE.fields_by_name['devices'].message_type = _CDEVICEAUTH_GETOWNAUTHORIZEDDEVICES_RESPONSE_DEVICE
_CDEVICEAUTH_GETUSEDAUTHORIZEDDEVICES_RESPONSE_DEVICE.containing_type = _CDEVICEAUTH_GETUSEDAUTHORIZEDDEVICES_RESPONSE
_CDEVICEAUTH_GETUSEDAUTHORIZEDDEVICES_RESPONSE.fields_by_name['devices'].message_type = _CDEVICEAUTH_GETUSEDAUTHORIZEDDEVICES_RESPONSE_DEVICE
_CDEVICEAUTH_GETAUTHORIZEDBORROWERS_RESPONSE_BORROWER.containing_type = _CDEVICEAUTH_GETAUTHORIZEDBORROWERS_RESPONSE
_CDEVICEAUTH_GETAUTHORIZEDBORROWERS_RESPONSE.fields_by_name['borrowers'].message_type = _CDEVICEAUTH_GETAUTHORIZEDBORROWERS_RESPONSE_BORROWER
_CDEVICEAUTH_GETAUTHORIZEDASBORROWER_RESPONSE_LENDER.containing_type = _CDEVICEAUTH_GETAUTHORIZEDASBORROWER_RESPONSE
_CDEVICEAUTH_GETAUTHORIZEDASBORROWER_RESPONSE.fields_by_name['lenders'].message_type = _CDEVICEAUTH_GETAUTHORIZEDASBORROWER_RESPONSE_LENDER
_CDEVICEAUTH_GETEXCLUDEDGAMESINLIBRARY_RESPONSE_EXCLUDEDGAME.containing_type = _CDEVICEAUTH_GETEXCLUDEDGAMESINLIBRARY_RESPONSE
_CDEVICEAUTH_GETEXCLUDEDGAMESINLIBRARY_RESPONSE.fields_by_name['excluded_games'].message_type = _CDEVICEAUTH_GETEXCLUDEDGAMESINLIBRARY_RESPONSE_EXCLUDEDGAME
_CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE_GAMEHISTORY.containing_type = _CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE
_CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE_LENDERHISTORY.fields_by_name['game_history'].message_type = _CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE_GAMEHISTORY
_CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE_LENDERHISTORY.containing_type = _CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE
_CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE.fields_by_name['lender_history'].message_type = _CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE_LENDERHISTORY
DESCRIPTOR.message_types_by_name['CDeviceAuth_GetOwnAuthorizedDevices_Request'] = _CDEVICEAUTH_GETOWNAUTHORIZEDDEVICES_REQUEST
DESCRIPTOR.message_types_by_name['CDeviceAuth_GetOwnAuthorizedDevices_Response'] = _CDEVICEAUTH_GETOWNAUTHORIZEDDEVICES_RESPONSE
DESCRIPTOR.message_types_by_name['CDeviceAuth_AcceptAuthorizationRequest_Request'] = _CDEVICEAUTH_ACCEPTAUTHORIZATIONREQUEST_REQUEST
DESCRIPTOR.message_types_by_name['CDeviceAuth_AcceptAuthorizationRequest_Response'] = _CDEVICEAUTH_ACCEPTAUTHORIZATIONREQUEST_RESPONSE
DESCRIPTOR.message_types_by_name['CDeviceAuth_AuthorizeRemoteDevice_Request'] = _CDEVICEAUTH_AUTHORIZEREMOTEDEVICE_REQUEST
DESCRIPTOR.message_types_by_name['CDeviceAuth_AuthorizeRemoteDevice_Response'] = _CDEVICEAUTH_AUTHORIZEREMOTEDEVICE_RESPONSE
DESCRIPTOR.message_types_by_name['CDeviceAuth_DeauthorizeRemoteDevice_Request'] = _CDEVICEAUTH_DEAUTHORIZEREMOTEDEVICE_REQUEST
DESCRIPTOR.message_types_by_name['CDeviceAuth_DeauthorizeRemoteDevice_Response'] = _CDEVICEAUTH_DEAUTHORIZEREMOTEDEVICE_RESPONSE
DESCRIPTOR.message_types_by_name['CDeviceAuth_GetUsedAuthorizedDevices_Request'] = _CDEVICEAUTH_GETUSEDAUTHORIZEDDEVICES_REQUEST
DESCRIPTOR.message_types_by_name['CDeviceAuth_GetUsedAuthorizedDevices_Response'] = _CDEVICEAUTH_GETUSEDAUTHORIZEDDEVICES_RESPONSE
DESCRIPTOR.message_types_by_name['CDeviceAuth_GetAuthorizedBorrowers_Request'] = _CDEVICEAUTH_GETAUTHORIZEDBORROWERS_REQUEST
DESCRIPTOR.message_types_by_name['CDeviceAuth_GetAuthorizedBorrowers_Response'] = _CDEVICEAUTH_GETAUTHORIZEDBORROWERS_RESPONSE
DESCRIPTOR.message_types_by_name['CDeviceAuth_AddAuthorizedBorrowers_Request'] = _CDEVICEAUTH_ADDAUTHORIZEDBORROWERS_REQUEST
DESCRIPTOR.message_types_by_name['CDeviceAuth_AddAuthorizedBorrowers_Response'] = _CDEVICEAUTH_ADDAUTHORIZEDBORROWERS_RESPONSE
DESCRIPTOR.message_types_by_name['CDeviceAuth_RemoveAuthorizedBorrowers_Request'] = _CDEVICEAUTH_REMOVEAUTHORIZEDBORROWERS_REQUEST
DESCRIPTOR.message_types_by_name['CDeviceAuth_RemoveAuthorizedBorrowers_Response'] = _CDEVICEAUTH_REMOVEAUTHORIZEDBORROWERS_RESPONSE
DESCRIPTOR.message_types_by_name['CDeviceAuth_GetAuthorizedAsBorrower_Request'] = _CDEVICEAUTH_GETAUTHORIZEDASBORROWER_REQUEST
DESCRIPTOR.message_types_by_name['CDeviceAuth_GetAuthorizedAsBorrower_Response'] = _CDEVICEAUTH_GETAUTHORIZEDASBORROWER_RESPONSE
DESCRIPTOR.message_types_by_name['CDeviceAuth_GetExcludedGamesInLibrary_Request'] = _CDEVICEAUTH_GETEXCLUDEDGAMESINLIBRARY_REQUEST
DESCRIPTOR.message_types_by_name['CDeviceAuth_GetExcludedGamesInLibrary_Response'] = _CDEVICEAUTH_GETEXCLUDEDGAMESINLIBRARY_RESPONSE
DESCRIPTOR.message_types_by_name['CDeviceAuth_GetBorrowerPlayHistory_Request'] = _CDEVICEAUTH_GETBORROWERPLAYHISTORY_REQUEST
DESCRIPTOR.message_types_by_name['CDeviceAuth_GetBorrowerPlayHistory_Response'] = _CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CDeviceAuth_GetOwnAuthorizedDevices_Request = _reflection.GeneratedProtocolMessageType('CDeviceAuth_GetOwnAuthorizedDevices_Request', (_message.Message,), {
  'DESCRIPTOR' : _CDEVICEAUTH_GETOWNAUTHORIZEDDEVICES_REQUEST,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_GetOwnAuthorizedDevices_Request)
  })
_sym_db.RegisterMessage(CDeviceAuth_GetOwnAuthorizedDevices_Request)

CDeviceAuth_GetOwnAuthorizedDevices_Response = _reflection.GeneratedProtocolMessageType('CDeviceAuth_GetOwnAuthorizedDevices_Response', (_message.Message,), {

  'Device' : _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {
    'DESCRIPTOR' : _CDEVICEAUTH_GETOWNAUTHORIZEDDEVICES_RESPONSE_DEVICE,
    '__module__' : 'steammessages_deviceauth_pb2'
    # @@protoc_insertion_point(class_scope:CDeviceAuth_GetOwnAuthorizedDevices_Response.Device)
    })
  ,
  'DESCRIPTOR' : _CDEVICEAUTH_GETOWNAUTHORIZEDDEVICES_RESPONSE,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_GetOwnAuthorizedDevices_Response)
  })
_sym_db.RegisterMessage(CDeviceAuth_GetOwnAuthorizedDevices_Response)
_sym_db.RegisterMessage(CDeviceAuth_GetOwnAuthorizedDevices_Response.Device)

CDeviceAuth_AcceptAuthorizationRequest_Request = _reflection.GeneratedProtocolMessageType('CDeviceAuth_AcceptAuthorizationRequest_Request', (_message.Message,), {
  'DESCRIPTOR' : _CDEVICEAUTH_ACCEPTAUTHORIZATIONREQUEST_REQUEST,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_AcceptAuthorizationRequest_Request)
  })
_sym_db.RegisterMessage(CDeviceAuth_AcceptAuthorizationRequest_Request)

CDeviceAuth_AcceptAuthorizationRequest_Response = _reflection.GeneratedProtocolMessageType('CDeviceAuth_AcceptAuthorizationRequest_Response', (_message.Message,), {
  'DESCRIPTOR' : _CDEVICEAUTH_ACCEPTAUTHORIZATIONREQUEST_RESPONSE,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_AcceptAuthorizationRequest_Response)
  })
_sym_db.RegisterMessage(CDeviceAuth_AcceptAuthorizationRequest_Response)

CDeviceAuth_AuthorizeRemoteDevice_Request = _reflection.GeneratedProtocolMessageType('CDeviceAuth_AuthorizeRemoteDevice_Request', (_message.Message,), {
  'DESCRIPTOR' : _CDEVICEAUTH_AUTHORIZEREMOTEDEVICE_REQUEST,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_AuthorizeRemoteDevice_Request)
  })
_sym_db.RegisterMessage(CDeviceAuth_AuthorizeRemoteDevice_Request)

CDeviceAuth_AuthorizeRemoteDevice_Response = _reflection.GeneratedProtocolMessageType('CDeviceAuth_AuthorizeRemoteDevice_Response', (_message.Message,), {
  'DESCRIPTOR' : _CDEVICEAUTH_AUTHORIZEREMOTEDEVICE_RESPONSE,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_AuthorizeRemoteDevice_Response)
  })
_sym_db.RegisterMessage(CDeviceAuth_AuthorizeRemoteDevice_Response)

CDeviceAuth_DeauthorizeRemoteDevice_Request = _reflection.GeneratedProtocolMessageType('CDeviceAuth_DeauthorizeRemoteDevice_Request', (_message.Message,), {
  'DESCRIPTOR' : _CDEVICEAUTH_DEAUTHORIZEREMOTEDEVICE_REQUEST,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_DeauthorizeRemoteDevice_Request)
  })
_sym_db.RegisterMessage(CDeviceAuth_DeauthorizeRemoteDevice_Request)

CDeviceAuth_DeauthorizeRemoteDevice_Response = _reflection.GeneratedProtocolMessageType('CDeviceAuth_DeauthorizeRemoteDevice_Response', (_message.Message,), {
  'DESCRIPTOR' : _CDEVICEAUTH_DEAUTHORIZEREMOTEDEVICE_RESPONSE,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_DeauthorizeRemoteDevice_Response)
  })
_sym_db.RegisterMessage(CDeviceAuth_DeauthorizeRemoteDevice_Response)

CDeviceAuth_GetUsedAuthorizedDevices_Request = _reflection.GeneratedProtocolMessageType('CDeviceAuth_GetUsedAuthorizedDevices_Request', (_message.Message,), {
  'DESCRIPTOR' : _CDEVICEAUTH_GETUSEDAUTHORIZEDDEVICES_REQUEST,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_GetUsedAuthorizedDevices_Request)
  })
_sym_db.RegisterMessage(CDeviceAuth_GetUsedAuthorizedDevices_Request)

CDeviceAuth_GetUsedAuthorizedDevices_Response = _reflection.GeneratedProtocolMessageType('CDeviceAuth_GetUsedAuthorizedDevices_Response', (_message.Message,), {

  'Device' : _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {
    'DESCRIPTOR' : _CDEVICEAUTH_GETUSEDAUTHORIZEDDEVICES_RESPONSE_DEVICE,
    '__module__' : 'steammessages_deviceauth_pb2'
    # @@protoc_insertion_point(class_scope:CDeviceAuth_GetUsedAuthorizedDevices_Response.Device)
    })
  ,
  'DESCRIPTOR' : _CDEVICEAUTH_GETUSEDAUTHORIZEDDEVICES_RESPONSE,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_GetUsedAuthorizedDevices_Response)
  })
_sym_db.RegisterMessage(CDeviceAuth_GetUsedAuthorizedDevices_Response)
_sym_db.RegisterMessage(CDeviceAuth_GetUsedAuthorizedDevices_Response.Device)

CDeviceAuth_GetAuthorizedBorrowers_Request = _reflection.GeneratedProtocolMessageType('CDeviceAuth_GetAuthorizedBorrowers_Request', (_message.Message,), {
  'DESCRIPTOR' : _CDEVICEAUTH_GETAUTHORIZEDBORROWERS_REQUEST,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_GetAuthorizedBorrowers_Request)
  })
_sym_db.RegisterMessage(CDeviceAuth_GetAuthorizedBorrowers_Request)

CDeviceAuth_GetAuthorizedBorrowers_Response = _reflection.GeneratedProtocolMessageType('CDeviceAuth_GetAuthorizedBorrowers_Response', (_message.Message,), {

  'Borrower' : _reflection.GeneratedProtocolMessageType('Borrower', (_message.Message,), {
    'DESCRIPTOR' : _CDEVICEAUTH_GETAUTHORIZEDBORROWERS_RESPONSE_BORROWER,
    '__module__' : 'steammessages_deviceauth_pb2'
    # @@protoc_insertion_point(class_scope:CDeviceAuth_GetAuthorizedBorrowers_Response.Borrower)
    })
  ,
  'DESCRIPTOR' : _CDEVICEAUTH_GETAUTHORIZEDBORROWERS_RESPONSE,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_GetAuthorizedBorrowers_Response)
  })
_sym_db.RegisterMessage(CDeviceAuth_GetAuthorizedBorrowers_Response)
_sym_db.RegisterMessage(CDeviceAuth_GetAuthorizedBorrowers_Response.Borrower)

CDeviceAuth_AddAuthorizedBorrowers_Request = _reflection.GeneratedProtocolMessageType('CDeviceAuth_AddAuthorizedBorrowers_Request', (_message.Message,), {
  'DESCRIPTOR' : _CDEVICEAUTH_ADDAUTHORIZEDBORROWERS_REQUEST,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_AddAuthorizedBorrowers_Request)
  })
_sym_db.RegisterMessage(CDeviceAuth_AddAuthorizedBorrowers_Request)

CDeviceAuth_AddAuthorizedBorrowers_Response = _reflection.GeneratedProtocolMessageType('CDeviceAuth_AddAuthorizedBorrowers_Response', (_message.Message,), {
  'DESCRIPTOR' : _CDEVICEAUTH_ADDAUTHORIZEDBORROWERS_RESPONSE,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_AddAuthorizedBorrowers_Response)
  })
_sym_db.RegisterMessage(CDeviceAuth_AddAuthorizedBorrowers_Response)

CDeviceAuth_RemoveAuthorizedBorrowers_Request = _reflection.GeneratedProtocolMessageType('CDeviceAuth_RemoveAuthorizedBorrowers_Request', (_message.Message,), {
  'DESCRIPTOR' : _CDEVICEAUTH_REMOVEAUTHORIZEDBORROWERS_REQUEST,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_RemoveAuthorizedBorrowers_Request)
  })
_sym_db.RegisterMessage(CDeviceAuth_RemoveAuthorizedBorrowers_Request)

CDeviceAuth_RemoveAuthorizedBorrowers_Response = _reflection.GeneratedProtocolMessageType('CDeviceAuth_RemoveAuthorizedBorrowers_Response', (_message.Message,), {
  'DESCRIPTOR' : _CDEVICEAUTH_REMOVEAUTHORIZEDBORROWERS_RESPONSE,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_RemoveAuthorizedBorrowers_Response)
  })
_sym_db.RegisterMessage(CDeviceAuth_RemoveAuthorizedBorrowers_Response)

CDeviceAuth_GetAuthorizedAsBorrower_Request = _reflection.GeneratedProtocolMessageType('CDeviceAuth_GetAuthorizedAsBorrower_Request', (_message.Message,), {
  'DESCRIPTOR' : _CDEVICEAUTH_GETAUTHORIZEDASBORROWER_REQUEST,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_GetAuthorizedAsBorrower_Request)
  })
_sym_db.RegisterMessage(CDeviceAuth_GetAuthorizedAsBorrower_Request)

CDeviceAuth_GetAuthorizedAsBorrower_Response = _reflection.GeneratedProtocolMessageType('CDeviceAuth_GetAuthorizedAsBorrower_Response', (_message.Message,), {

  'Lender' : _reflection.GeneratedProtocolMessageType('Lender', (_message.Message,), {
    'DESCRIPTOR' : _CDEVICEAUTH_GETAUTHORIZEDASBORROWER_RESPONSE_LENDER,
    '__module__' : 'steammessages_deviceauth_pb2'
    # @@protoc_insertion_point(class_scope:CDeviceAuth_GetAuthorizedAsBorrower_Response.Lender)
    })
  ,
  'DESCRIPTOR' : _CDEVICEAUTH_GETAUTHORIZEDASBORROWER_RESPONSE,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_GetAuthorizedAsBorrower_Response)
  })
_sym_db.RegisterMessage(CDeviceAuth_GetAuthorizedAsBorrower_Response)
_sym_db.RegisterMessage(CDeviceAuth_GetAuthorizedAsBorrower_Response.Lender)

CDeviceAuth_GetExcludedGamesInLibrary_Request = _reflection.GeneratedProtocolMessageType('CDeviceAuth_GetExcludedGamesInLibrary_Request', (_message.Message,), {
  'DESCRIPTOR' : _CDEVICEAUTH_GETEXCLUDEDGAMESINLIBRARY_REQUEST,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_GetExcludedGamesInLibrary_Request)
  })
_sym_db.RegisterMessage(CDeviceAuth_GetExcludedGamesInLibrary_Request)

CDeviceAuth_GetExcludedGamesInLibrary_Response = _reflection.GeneratedProtocolMessageType('CDeviceAuth_GetExcludedGamesInLibrary_Response', (_message.Message,), {

  'ExcludedGame' : _reflection.GeneratedProtocolMessageType('ExcludedGame', (_message.Message,), {
    'DESCRIPTOR' : _CDEVICEAUTH_GETEXCLUDEDGAMESINLIBRARY_RESPONSE_EXCLUDEDGAME,
    '__module__' : 'steammessages_deviceauth_pb2'
    # @@protoc_insertion_point(class_scope:CDeviceAuth_GetExcludedGamesInLibrary_Response.ExcludedGame)
    })
  ,
  'DESCRIPTOR' : _CDEVICEAUTH_GETEXCLUDEDGAMESINLIBRARY_RESPONSE,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_GetExcludedGamesInLibrary_Response)
  })
_sym_db.RegisterMessage(CDeviceAuth_GetExcludedGamesInLibrary_Response)
_sym_db.RegisterMessage(CDeviceAuth_GetExcludedGamesInLibrary_Response.ExcludedGame)

CDeviceAuth_GetBorrowerPlayHistory_Request = _reflection.GeneratedProtocolMessageType('CDeviceAuth_GetBorrowerPlayHistory_Request', (_message.Message,), {
  'DESCRIPTOR' : _CDEVICEAUTH_GETBORROWERPLAYHISTORY_REQUEST,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_GetBorrowerPlayHistory_Request)
  })
_sym_db.RegisterMessage(CDeviceAuth_GetBorrowerPlayHistory_Request)

CDeviceAuth_GetBorrowerPlayHistory_Response = _reflection.GeneratedProtocolMessageType('CDeviceAuth_GetBorrowerPlayHistory_Response', (_message.Message,), {

  'GameHistory' : _reflection.GeneratedProtocolMessageType('GameHistory', (_message.Message,), {
    'DESCRIPTOR' : _CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE_GAMEHISTORY,
    '__module__' : 'steammessages_deviceauth_pb2'
    # @@protoc_insertion_point(class_scope:CDeviceAuth_GetBorrowerPlayHistory_Response.GameHistory)
    })
  ,

  'LenderHistory' : _reflection.GeneratedProtocolMessageType('LenderHistory', (_message.Message,), {
    'DESCRIPTOR' : _CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE_LENDERHISTORY,
    '__module__' : 'steammessages_deviceauth_pb2'
    # @@protoc_insertion_point(class_scope:CDeviceAuth_GetBorrowerPlayHistory_Response.LenderHistory)
    })
  ,
  'DESCRIPTOR' : _CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE,
  '__module__' : 'steammessages_deviceauth_pb2'
  # @@protoc_insertion_point(class_scope:CDeviceAuth_GetBorrowerPlayHistory_Response)
  })
_sym_db.RegisterMessage(CDeviceAuth_GetBorrowerPlayHistory_Response)
_sym_db.RegisterMessage(CDeviceAuth_GetBorrowerPlayHistory_Response.GameHistory)
_sym_db.RegisterMessage(CDeviceAuth_GetBorrowerPlayHistory_Response.LenderHistory)


DESCRIPTOR._options = None

_DEVICEAUTH = _descriptor.ServiceDescriptor(
  name='DeviceAuth',
  full_name='DeviceAuth',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030 Library Sharing settings service',
  create_key=_descriptor._internal_create_key,
  serialized_start=2929,
  serialized_end=4915,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetOwnAuthorizedDevices',
    full_name='DeviceAuth.GetOwnAuthorizedDevices',
    index=0,
    containing_service=None,
    input_type=_CDEVICEAUTH_GETOWNAUTHORIZEDDEVICES_REQUEST,
    output_type=_CDEVICEAUTH_GETOWNAUTHORIZEDDEVICES_RESPONSE,
    serialized_options=b'\202\265\030\036Get list of authorized devices',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AcceptAuthorizationRequest',
    full_name='DeviceAuth.AcceptAuthorizationRequest',
    index=1,
    containing_service=None,
    input_type=_CDEVICEAUTH_ACCEPTAUTHORIZATIONREQUEST_REQUEST,
    output_type=_CDEVICEAUTH_ACCEPTAUTHORIZATIONREQUEST_RESPONSE,
    serialized_options=b'\202\265\0300Accept an authorization request by another users',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AuthorizeRemoteDevice',
    full_name='DeviceAuth.AuthorizeRemoteDevice',
    index=2,
    containing_service=None,
    input_type=_CDEVICEAUTH_AUTHORIZEREMOTEDEVICE_REQUEST,
    output_type=_CDEVICEAUTH_AUTHORIZEREMOTEDEVICE_RESPONSE,
    serialized_options=b'\202\265\0304Authorize own remote device that has pending request',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeauthorizeRemoteDevice',
    full_name='DeviceAuth.DeauthorizeRemoteDevice',
    index=3,
    containing_service=None,
    input_type=_CDEVICEAUTH_DEAUTHORIZEREMOTEDEVICE_REQUEST,
    output_type=_CDEVICEAUTH_DEAUTHORIZEREMOTEDEVICE_RESPONSE,
    serialized_options=b'\202\265\030\037Revoke own device authorization',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUsedAuthorizedDevices',
    full_name='DeviceAuth.GetUsedAuthorizedDevices',
    index=4,
    containing_service=None,
    input_type=_CDEVICEAUTH_GETUSEDAUTHORIZEDDEVICES_REQUEST,
    output_type=_CDEVICEAUTH_GETUSEDAUTHORIZEDDEVICES_RESPONSE,
    serialized_options=b'\202\265\030<Get list of authorized devices user played borrowed games on',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAuthorizedBorrowers',
    full_name='DeviceAuth.GetAuthorizedBorrowers',
    index=5,
    containing_service=None,
    input_type=_CDEVICEAUTH_GETAUTHORIZEDBORROWERS_REQUEST,
    output_type=_CDEVICEAUTH_GETAUTHORIZEDBORROWERS_RESPONSE,
    serialized_options=b'\202\265\0309Get list of users that can borrow on an authorized device',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddAuthorizedBorrowers',
    full_name='DeviceAuth.AddAuthorizedBorrowers',
    index=6,
    containing_service=None,
    input_type=_CDEVICEAUTH_ADDAUTHORIZEDBORROWERS_REQUEST,
    output_type=_CDEVICEAUTH_ADDAUTHORIZEDBORROWERS_RESPONSE,
    serialized_options=b'\202\265\0307Add users that can borrow on limited authorized devices',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveAuthorizedBorrowers',
    full_name='DeviceAuth.RemoveAuthorizedBorrowers',
    index=7,
    containing_service=None,
    input_type=_CDEVICEAUTH_REMOVEAUTHORIZEDBORROWERS_REQUEST,
    output_type=_CDEVICEAUTH_REMOVEAUTHORIZEDBORROWERS_RESPONSE,
    serialized_options=b'\202\265\030:Remove users that can borrow on limited authorized devices',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAuthorizedAsBorrower',
    full_name='DeviceAuth.GetAuthorizedAsBorrower',
    index=8,
    containing_service=None,
    input_type=_CDEVICEAUTH_GETAUTHORIZEDASBORROWER_REQUEST,
    output_type=_CDEVICEAUTH_GETAUTHORIZEDASBORROWER_RESPONSE,
    serialized_options=b'\202\265\030=Get list of lenders that authorized given account as borrower',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExcludedGamesInLibrary',
    full_name='DeviceAuth.GetExcludedGamesInLibrary',
    index=9,
    containing_service=None,
    input_type=_CDEVICEAUTH_GETEXCLUDEDGAMESINLIBRARY_REQUEST,
    output_type=_CDEVICEAUTH_GETEXCLUDEDGAMESINLIBRARY_RESPONSE,
    serialized_options=b'\202\265\030-Get list of excluded games in lenders library',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBorrowerPlayHistory',
    full_name='DeviceAuth.GetBorrowerPlayHistory',
    index=10,
    containing_service=None,
    input_type=_CDEVICEAUTH_GETBORROWERPLAYHISTORY_REQUEST,
    output_type=_CDEVICEAUTH_GETBORROWERPLAYHISTORY_RESPONSE,
    serialized_options=b'\202\265\030!Get list played games as borrower',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DEVICEAUTH)

DESCRIPTOR.services_by_name['DeviceAuth'] = _DEVICEAUTH

DeviceAuth = service_reflection.GeneratedServiceType('DeviceAuth', (_service.Service,), dict(
  DESCRIPTOR = _DEVICEAUTH,
  __module__ = 'steammessages_deviceauth_pb2'
  ))

DeviceAuth_Stub = service_reflection.GeneratedServiceStubType('DeviceAuth_Stub', (DeviceAuth,), dict(
  DESCRIPTOR = _DEVICEAUTH,
  __module__ = 'steammessages_deviceauth_pb2'
  ))


# @@protoc_insertion_point(module_scope)
